@@ -4,6 +4,7 @@ from __future__ import annotations
 import asyncio
 from pprint import pformat
 import logging
+import re
 import socket
 from typing import Dict, List
 import uuid
@@ -135,7 +136,8 @@ class ControlPoint:
 
         self.socket.subscribe(self)
 
-        await self.socket.sendall(ControlPointProtocol.authorise(self.device_mac))
+        await self.socket.sendall(ControlPointProtocol.authorise(self.device_mac),
+                                  response_expected=False)
 
         try:
             self.logger.info('connect() waiting for authorisation')
@@ -147,7 +149,7 @@ class ControlPoint:
                 "Unable to authorise connection to ZCC.") from error
 
         await self.socket.sendall(ControlPointProtocol.start(
-            self.device_mac, self.access_token))
+            self.device_mac, self.access_token), response_expected=False)
 
         try:
             self.logger.info('connect() waiting for session start')
@@ -209,7 +211,7 @@ class ControlPoint:
         self.states_ready = self.loop.create_future()
 
         self.logger.info('__get_devices() getting properties')
-        await self.socket.sendall(ControlPointProtocol.get('properties'))
+        await self.socket.sendall(ControlPointProtocol.get('properties'), response_expected=False)
 
         try:
             await asyncio.wait_for(self.properties_ready,
@@ -221,7 +223,7 @@ class ControlPoint:
         await asyncio.sleep(ControlPointProtocol.DEVICE_GET_TIMEOUT)
 
         self.logger.info('__get_devices() getting actions')
-        await self.socket.sendall(ControlPointProtocol.get('actions'))
+        await self.socket.sendall(ControlPointProtocol.get('actions'), response_expected=False)
 
         try:
             await asyncio.wait_for(self.actions_ready,
@@ -233,7 +235,7 @@ class ControlPoint:
         await asyncio.sleep(ControlPointProtocol.DEVICE_GET_TIMEOUT)
 
         self.logger.info('__get_devices() getting states')
-        await self.socket.sendall(ControlPointProtocol.get('states'))
+        await self.socket.sendall(ControlPointProtocol.get('states'), response_expected=False)
 
         try:
             await asyncio.wait_for(self.states_ready,
