@@ -53,6 +53,9 @@ class ControlPointSocket:
             self.listen_task = asyncio.create_task(self.__listen())
         except asyncio.CancelledError:
             self.logger.error("connect() cancelled")
+            self.logger.error("connect() awating _listen cancellation")
+            await self.listen_task
+            self.logger.error("connect() received _listen cancellation")
         except ConnectionRefusedError as error:
             self.logger.error(
                 'ControlPointSocket() connection refused %s error from %s:%s',
@@ -102,6 +105,7 @@ class ControlPointSocket:
 
         self.logger.debug("__listen() socket closed")
 
+        self.listen_task = None  # Remove reference before closing
         self.close()
 
         for obs in self._observers:
